@@ -12,12 +12,22 @@
 #ifndef _LINK_CONNECTION_H_
 #define _LINK_CONNECTION_H_
 
-#include <glib/gmacros.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
-#include <sys/uio.h>
-#include <netdb.h>
+#ifdef G_OS_WIN32
+#  include <winsock2.h>
+#  undef interface		/* #defined as struct! */
+
+#  define iovec _WSABUF
+#  define iov_len len
+#  define iov_base buf
+
+#else
+#  include <sys/uio.h>
+#  include <netdb.h>
+#endif
 
 #include <linc/linc-types.h>
 #include <linc/linc-protocol.h>
@@ -29,7 +39,8 @@ G_BEGIN_DECLS
 #define LINK_IS_CONNECTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LINK_TYPE_CONNECTION))
 #define LINK_IS_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LINK_TYPE_CONNECTION))
 
-typedef enum { LINK_CONNECTING, LINK_CONNECTED, LINK_DISCONNECTED } LinkConnectionStatus;
+typedef enum { LINK_CONNECTING, LINK_CONNECTED, LINK_DISCONNECTED, LINK_TIMEOUT } LinkConnectionStatus;
+typedef enum { LINK_TIMEOUT_UNKNOWN, LINK_TIMEOUT_YES, LINK_TIMEOUT_NO } LinkTimeoutStatus;
 
 typedef struct _LinkWriteOpts         LinkWriteOpts;
 typedef struct _LinkConnectionPrivate LinkConnectionPrivate;
@@ -51,6 +62,12 @@ typedef struct {
 	LinkConnectionPrivate  *priv;
 
 	GSList                 *idle_broken_callbacks;
+
+	GMutex                 *timeout_mutex;
+	guint                   timeout_msec;
+	guint                   timeout_source_id; // protected by timeout_mutex
+	LinkTimeoutStatus       timeout_status;    // protected by timeout_mutex
+	void                   *tdata;             // "do not pollute the namespace"-hack (it's a GIOPThread*)
 } LinkConnection;
 
 typedef struct {
@@ -90,8 +107,8 @@ LinkConnection *link_connection_initiate (GType                 derived_type,
 					  ...);
 LinkConnectionStatus link_connection_try_reconnect (LinkConnection *cnx);
 
-gpointer link_connection_ref   (gpointer cnx);
-void     link_connection_unref (gpointer cnx);
+LinkConnection *link_connection_ref   (LinkConnection *cnx);
+void            link_connection_unref (LinkConnection *cnx);
 
 typedef enum {
 	LINK_IO_OK = 0,
@@ -143,6 +160,9 @@ void           link_connection_remove_broken_cb  (LinkConnection    *cnx,
 
 void           link_connections_close            (void);
 
+/* set the link timeout in miliseconds */
+extern void link_set_timeout (guint msec);
+
 G_END_DECLS
 
 #endif /* _LINK_CONNECTION_H */
