@@ -468,6 +468,33 @@ link_protocol_is_local_ipv46 (const LinkProtocolInfo *proto,
 #endif
 	return FALSE;
 #else   /*HAVE_GETADDRINFO*/	
+
+	/* Do simple check for INADDR_LOOPBACK first */
+	if (saddr->sa_family == AF_INET &&
+	    ((struct sockaddr_in *)saddr)->sin_addr.s_addr == htonl (INADDR_LOOPBACK)) {
+#ifdef LOCAL_DEBUG
+		/* I don't understand why g_warning() is used here,
+		 * but as the existing code does this if LOCAL_DEBUG
+		 * is defined and we are going to return TRUE, keep
+		 * doing it like that then... Not that I know if
+		 * anybody is using the LOCAL_DEBUG possibility?
+		 */
+		g_warning ("local ipv4 address");
+#endif
+		return TRUE;
+	}
+
+#ifdef AF_INET6
+	/* Then simple check for IPv6 loopback address */
+	if (saddr->sa_family == AF_INET6 &&
+	    IN6_IS_ADDR_LOOPBACK (saddr)) {
+#ifdef LOCAL_DEBUG
+		g_warning ("local ipv6 address");
+#endif
+		return TRUE;
+	}
+#endif
+
 	if (!local_hostent) {
 		LINK_RESOLV_SET_IPV6;
                 d_printf("%s:%s:%d:gethostbyname(%s)\n", __FILE__, __FUNCTION__, __LINE__, link_get_local_hostname ());
@@ -870,9 +897,8 @@ link_protocol_get_sockinfo_ipv4 (const LinkProtocolInfo  *proto,
 	if (ntohl (sa_in->sin_addr.s_addr) != INADDR_ANY) {
 		host = gethostbyaddr ((char *)&sa_in->sin_addr, 
                                       sizeof (struct in_addr), AF_INET);
-		if (!host)
-			return FALSE;
-		hname = host->h_name;
+		if (host)
+			hname = host->h_name;
 	}
 #endif
 	return link_protocol_get_sockinfo_ipv46 (hname, sa_in->sin_port, 
@@ -931,16 +957,12 @@ link_protocol_get_sockinfo_ipv6 (const LinkProtocolInfo  *proto,
 	if (memcmp (&sa_in6->sin6_addr, &in6addr_any, sizeof (struct in6_addr))) {
 
 #ifdef HAVE_GETNAMEINFO
-                if (getnameinfo((struct sockaddr *)sa_in6, sizeof(*sa_in6), hbuf, sizeof(hbuf), NULL, 0, NI_NAMEREQD))
-			return FALSE;
-		else
+                if (!getnameinfo((struct sockaddr *)sa_in6, sizeof(*sa_in6), hbuf, sizeof(hbuf), NULL, 0, NI_NAMEREQD))
 			hname = hbuf;
 	}
 #else
 		host = gethostbyaddr ((char *)&sa_in6->sin6_addr,
 				      sizeof (struct in6_addr), AF_INET6);
-		if (!host)
-			return FALSE;
 		if (host)
 			hname = host->h_name;
 	}
@@ -1012,7 +1034,7 @@ link_protocol_post_create_unix (int fd, struct sockaddr *saddr)
 	if (getuid() == 0) {
 		struct stat stat_buf;
 		if (!stat (link_tmpdir, &stat_buf))
-			fchown (fd, stat_buf.st_uid, -1);
+			chown (saddr_un->sun_path, stat_buf.st_uid, -1);
 	}
 #endif
 }
