@@ -22,12 +22,14 @@
 
 #include <config.h>
 #include <sys/types.h>
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 #include <stdio.h>
 #include <string.h>
 
 #include <gmodule.h>
-#include <glib/garray.h>
+#include <glib.h>
 
 #include <orbit/orbit.h>
 
